@@ -90,7 +90,9 @@ def do_action():
             # external_id = "d7a53cbe3e966c53ac64fde7355956560282158ecac8f3d2c770b474862f4756%40egi.eu@https%3A%2F%2Faai.egi.eu%2Foidc%2F"
             # logger.info(F"enforced external id: {external_id}")
         
-            external_id = unmask_from_bwidm(external_id)
+            potential_external_id = unmask_from_bwidm(external_id)
+            if potential_external_id is not None:
+                external_id = potential_external_id
 
 
             logger.debug(F"actual external id: {external_id}")
